@@ -92,75 +92,73 @@ void dump_status(int a);
 
 status_type 		status;
 cfg_type cfg = {
-	1,	/* statelog: write stdout into file */
+	.statelog = 1,		/* write stdout into file */
 #ifdef QUICKLOG
-	30,	/* qloglength: 30 minutes */
-	-1,	/* autoqlog: full quicklog */
+	.qloglength = 30,	/* 30 minutes */
+	.autoqlog = -1,		/* replay everything */
 #ifdef QLOGSTAMP
-	0,	/* timestamp: no timestamp */
+	.timestamp = 0,		/* don't timestamp quicklog */
 #endif /* ifdef QLOGSTAMP */
-	1,	/* flushqlog: flush */
+	.flushqlog = 1,		/* flush qlog at attach */
 #endif /* ifdef QUICKLOG */
 #ifdef DCCBOUNCE
-	0,	/* dccbounce: no */
+	.dccbounce = 0,		/* no dcc bounce */
+	.dccbindhost = NULL,	/* don't bind for dcc bounce */
 #endif /* ifdef DCCBOUNCE */
 #ifdef AUTOMODE
-	30,	/* automodedelay: 30 seconds */
+	.automodedelay = 30,	/* 30 seconds */
 #endif /* ifdef AUTOMODE */
 #ifdef INBOX
-	1,
+	.inbox = 1,		/* enable inbox */
 #endif /* ifdef INBOX */
-	0,	/* listenport: 0 */
-	2,	/* floodtimer */
-	5,	/* burstsize */
-	30,	/* jointries */
-	1,	/* getnick: disconnected */
-	60,	/* getnickinterval: 60 seconds */
-	0,	/* antiidle: no */
-	1,	/* nevergiveup: yes, never give up */
-	0,	/* jumprestricted: no */
-	90,	/* stonedtimeout: 90 seconds */
-	1,	/* rejoin: yes */
-	30,	/* connecttimeout: 30 seconds */
-	10,	/* reconnectdelay: 10 seconds */
-	0,	/* leave: no */
-	2,	/* chandiscon: part */
-	9,	/* maxnicklen: 9 chars */
-	3,	/* maxclients: 3 clients */
-	1,	/* usequitmsg: yes */
-	1,	/* autoaway: detach */
+	.listenport = 0,	/* no default */
+	.floodtimer = 2,	/* 2 seconds */
+	.burstsize = 5,		/* 5 messages per burst */
+	.jointries = 30,	/* try to join a channel 30 times */
+	.getnick = 1,		/* try to get nick while disconnected */
+	.getnickinterval = 60,	/* try to get nick every 60 seconds */
+	.antiidle = 0,		/* no anti-idle */
+	.nevergiveup = 1,	/* never give up connecting */
+	.jumprestricted = 0,	/* allow restricted servers */
+	.stonedtimeout = 90,	/* 90 seconds */
+	.rejoin = 1,		/* rejoin channels after disconnecting */
+	.connecttimeout = 30,	/* 30 seconds */
+	.reconnectdelay = 10,	/* 10 seconds */
+	.leave = 0,		/* don't leave channels on detach */
+	.chandiscon = 2,	/* part channels when disconnected */
+	.maxnicklen = 9,	/* 9 characters */
+	.maxclients = 3,	/* 3 clients */
+	.usequitmsg = 1,	/* use quit message as away message */
+	.autoaway = 1,		/* automatically set away at detach */
 #ifdef PRIVLOG
-	0,	/* privlog: no privlog */
+	.privlog = 0,		/* don't write private log */
 #endif /* ifdef PRIVLOG */
 
-	DEFAULT_NICKFILL,	/* nickfillchar */
-	
-#ifdef NEED_LOGGING
-	NULL,			/* logsuffix */
-#endif /* ifdef NEED_LOGGING */
-#ifdef DCCBOUNCE
-	NULL,			/* dccbindhost */
-#endif /* ifdef DCCBOUNCE */
-#ifdef NEED_CMDPASSWD
-	NULL,			/* cmdpasswd */
-#endif /* ifdef NEED_CMDPASSWD */
-	NULL,	/* username */
-	NULL,	/* realname */
-	NULL,	/* password */
-	NULL,	/* leavemsg */
-	NULL,	/* bind */
-	NULL,	/* listenhost */
-	NULL,	/* awaymsg */
-	NULL,	/* forwardmsg */
-	180,	/* forwardtime */
-	NULL,	/* channels */
-	NULL,	/* home */
-	NULL,	/* usermode */
+	.nickfillchar = DEFAULT_NICKFILL,
 
-	0,	/* no_idmsg_capab */
-	0,	/* qlog_no_my_quit */
-	NULL,	/* privmsg_fmt */
-	0,	/* newserv_disconn: none. see enum in miau.h */
+#ifdef NEED_LOGGING
+	.logsuffix = NULL,	/* no log suffix */
+#endif /* ifdef NEED_LOGGING */
+#ifdef NEED_CMDPASSWD
+	.cmdpasswd = NULL,	/* no default */
+#endif /* ifdef NEED_CMDPASSWD */
+	.username = NULL,	/* no default */
+	.realname = NULL,	/* no default */
+	.password = NULL,	/* no default */
+	.leavemsg = NULL,	/* no default */
+	.bind = NULL,		/* no default */
+	.listenhost = NULL,	/* no default */
+	.awaymsg = NULL,	/* no default */
+	.forwardmsg = NULL,	/* no default */
+	.forwardtime = 180,	/* 180 seconds */
+	.channels = NULL,	/* no default */
+	.home = NULL,		/* no default */
+	.usermode = NULL,	/* no default */
+
+	.no_identify_capab = 0,	/* allow CAPAB IDENTIFY-MSG */
+	.qlog_no_my_quit = 0,	/* don't strip my QUIT from quicklog */
+	.privmsg_fmt = NULL,	/* no privmsg_fmt */
+	.newserv_disconn = 0,	/* none. see enum in miau.h */
 };
 nicknames_type		nicknames;
 
@@ -213,7 +211,7 @@ free_resources(void)
 #ifdef ONCONNECT
 	LLIST_EMPTY(onconnect_actions.head, &onconnect_actions);
 #endif /* ifdef ONCONNECT */
-	
+
 	FREE(cfg.username);
 	FREE(cfg.realname);
 	FREE(cfg.password);
@@ -330,7 +328,7 @@ escape(void)
 	xfree(i_newclient.nickname);
 	xfree(i_newclient.username);
 	xfree(i_newclient.hostname);
-	
+
 	/* We're done. */
 	error(MIAU_ERREXIT);
 } /* static void escape(void) */
@@ -344,7 +342,7 @@ static void
 read_cfg(void)
 {
 	int	ret;
-	
+
 	/* Set current server to point the fallback server. */
 	i_server.current = servers.servers.head;
 
@@ -356,7 +354,7 @@ read_cfg(void)
 		llist_delete(node, &servers.servers);
 	LLIST_WALK_F;
 	servers.amount = 1;
-	
+
 	/* Read configuration file. */
 	ret = parse_cfg(MIAURC);
 	if (ret == -1) {
@@ -584,7 +582,7 @@ dump_status(int a)
 		dump_add("    }"); dump_dump();
 	LLIST_WALK_F;
 	dump_dump();
-	
+
 	dump_string("passive_channels:");
 	LLIST_WALK_H(passive_channels.head, channel_type *);
 		dump_add("    {");
@@ -708,7 +706,7 @@ proceed_timer_safe(int *timer, const int warn, const int exceed,
 	if (repeat != 0 && *timer > warn && (*timer - warn) % repeat == 0) {
 		return 1;
 	}
-	
+
 	return 0;
 } /* static int proceed_timer_safe(int *timer, const int warn, const int exceed,
 		const int repeat) */
@@ -743,12 +741,12 @@ create_listen(void)
 
 		exit(ERR_CODE_NETWORK);
 	}
-	
+
 	if (! sock_listen(listensocket)) {
 		error(SOCK_ERRLISTEN);
 		exit(ERR_CODE_NETWORK);
 	}
-	
+
 	if (cfg.listenhost) {
 		report(SOCK_LISTENOKHOST, cfg.listenhost, cfg.listenport);
 	} else {
@@ -852,7 +850,7 @@ rehash(int sigparam)
 	/* Free non-must parameters. */
 	free_resources();
 	cfg.listenport = 0;
-	
+
 #ifdef CHANLOG
 	/* Close open logfiles. */
 	LLIST_WALK_H(active_channels.head, channel_type *);
@@ -860,7 +858,7 @@ rehash(int sigparam)
 	LLIST_WALK_F;
 	global_logtype = 0;	/* No logging by default. */
 #endif /* idef CHANLOG */
-	
+
 	/* Re-read miaurc and check results. */
 	read_cfg();
 	if (check_config() != 0) {
@@ -868,7 +866,7 @@ rehash(int sigparam)
 				status.nickname,
 				CLNT_MIAURCBEENWARNED);
 	}
-		
+
 
 	/*
 	 * realname, username, password and listenport are required and we want
@@ -879,7 +877,7 @@ rehash(int sigparam)
 	if (cfg.username == NULL) { cfg.username = xstrdup(oldusername); }
 	if (cfg.password == NULL) { cfg.password = xstrdup(oldpassword); }
 	if (cfg.listenport == 0) { cfg.listenport = oldlistenport; }
-	
+
 #ifdef CHANLOG
 	/* Open logs. */
 	LLIST_WALK_H(active_channels.head, channel_type *);
@@ -922,7 +920,7 @@ rehash(int sigparam)
 		status.got_nick = 0;
 		timers.nickname = cfg.getnickinterval;
 	}
-	
+
 	/* Next nick we try is the first one on the list. */
 	nicknames.next = NICK_FIRST;
 
@@ -961,7 +959,7 @@ rehash(int sigparam)
 		fclose(inbox);
 		inbox = NULL;
 	}
-	
+
 	/* We should start logging. */
 	if (cfg.inbox == 1 && inbox == NULL) {
 		inbox = fopen(FILE_INBOX, "a+");
@@ -974,7 +972,7 @@ rehash(int sigparam)
 	/* Reopen log-file. */
 	/*
 	 * Hmm, this doesn't work.
-	 * 
+	 *
 	if (! freopen(FILE_LOG, "a", stdout)) {
 		irc_mnotice(&c_clients, status.nickname, MIAU_ERRLOGCONN);
 		freopen("/dev/null", "a", stdout);
@@ -1026,7 +1024,7 @@ clients_left(const char *reason)
 	}
 
 	chans = (char *) xcalloc(1, 1);
-	
+
 	/*
 	 * When all clients have detached from miau...
 	 *
@@ -1083,7 +1081,7 @@ clients_left(const char *reason)
 		}
 		else
 #endif /* ifdef CHANLOG */
-		
+
 		/* We want to send an ACTION on each channel. */
 		if (! cfg.leave && cfg.leavemsg != NULL) {
 			channel = strtok(chans + 1, ",");
@@ -1101,7 +1099,7 @@ clients_left(const char *reason)
 			irc_write(&c_server, "PART %s :%s",
 					chans + 1, leavemsg);
 		}
-		
+
 		/* Ok, we just want to part channels. */
 		else if (cfg.leave && cfg.leavemsg == NULL) {
 			report(MIAU_LEAVING);
@@ -1139,7 +1137,7 @@ check_timers(void)
 		return;
 	}
 	oldtime = newtime;
-	
+
 	/*
 	 * If cfg.floodtimer second(s) have elapsed (since last allowance) allow
 	 * sending anohter message. Don't forget to limit the counter to
@@ -1185,12 +1183,12 @@ check_timers(void)
 		switch (proceed_timer_safe(&client_con->timer, 60, 120, 10)) {
 			case 0:
 				break;
-				
+
 			case 1:
 				irc_write(client_con, "PING :%s",
 						i_server.realname);
 				break;
-				
+
 			case 2:
 				/* (single client, message, error, echo, no) */
 				client_drop(client_con, CLNT_STONED,
@@ -1203,7 +1201,7 @@ check_timers(void)
 
 	if (c_clients.connected == 0) {
 		/* Client is not connected. Anti-idle. */
-		if (cfg.antiidle && proceed_timer(&timers.antiidle, 0, 
+		if (cfg.antiidle && proceed_timer(&timers.antiidle, 0,
 					cfg.antiidle * 60) == 2) {
 			irc_write(&c_server, "PRIVMSG");
 		}
@@ -1273,10 +1271,10 @@ check_timers(void)
 		/* Client is connecting... */
 		switch (proceed_timer(&c_newclient.timer, 0, 30)) {
 			case 0:
-				
+
 			case 1:
 				break;
-				
+
 			case 2:
 				if (status.init) {
 					error(CLNT_AUTHFAIL);
@@ -1355,7 +1353,7 @@ check_timers(void)
 		if (proceed_timer(&timers.join, 0, JOINTRYINTERVAL) == 2) {
 			channel_join_list(LIST_PASSIVE, 0, NULL);
 		}
-	}			
+	}
 
 	/* Handle forwarded messages. */
 	if (cfg.forwardmsg) {
@@ -1386,11 +1384,11 @@ check_timers(void)
 					/* redundant, but makes it clearer */
 					forwardmsgsize = 0;
 				}
-				
+
 				break;
 		}
 	}
-	
+
 #ifdef AUTOMODE
 	/* Act as op-o-matic. */
 	if (status.automodes > 0 && proceed_timer(&timers.automode,
@@ -1500,7 +1498,7 @@ get_nick(char *format)
 		/* Getting nick, increase sent NICK-command counter. */
 		status.getting_nick++;
 		irc_write(&c_server, "NICK %s", status.nickname);
-		
+
 		xfree(badnick);
 	}
 	status.got_nick = 0;
@@ -1570,7 +1568,7 @@ fakeconnect(connection_type *newclient)
 
 #ifdef ASCIIART
 	/* Print a pretty picture. */
-	
+
 	/* Cats sleep when they want to. */
 	pic = rand() % 2;
 
@@ -1622,7 +1620,7 @@ fakeconnect(connection_type *newclient)
 			xfree(i_client.nickname);
 			i_client.nickname = xstrdup(status.nickname);
 		}
-		
+
 		/*
 		 * And we were away and didn't have hand-set away-message,
 		 * remove away-status.
@@ -1643,7 +1641,7 @@ fakeconnect(connection_type *newclient)
 				status.nickname);
 	}
 
-	/* 
+	/*
 	 * Ok, client knows what's going on. If we're connected to server,
 	 * we have things to do, mister.
 	 */
@@ -1655,15 +1653,15 @@ fakeconnect(connection_type *newclient)
 		} else {
 			qlog = cfg.autoqlog;
 		}
-		
+
 		if (qlog > 0) {
 			qlog_check(qlog * 60);
 		}
 #endif /* QUICKLOG */
 
-		/* 
+		/*
 		 * First of all, join passive channels.
-		 * 
+		 *
 		 * Passive channels are channels that are either defined
 		 * in miaurc and are not yet joined or channels, that we
 		 * were on when clients detached.
@@ -1789,11 +1787,11 @@ read_newclient(void)
 	int t;
 
 	t = irc_read(&c_newclient);
-	
+
 	if (t <= 0) {
 		return t;
 	}
-	
+
 	c_newclient.buffer[30] = 0;
 	command = strtok(c_newclient.buffer, " ");
 	param = strtok(NULL, "\0");
@@ -1873,7 +1871,7 @@ read_newclient(void)
 
 		fakeconnect(newclient);
 
-		/* 
+		/*
 		 * Reporting number of connected clients
 		 * is irrevelant if only one is allowed at
 		 * a time.
@@ -2024,7 +2022,7 @@ miau_commands(char *command, char *param, connection_type *client)
 			minutes = keep % 60;
 			hours = (keep / 60) % 24;
 			days = keep / 1440;
-			
+
 			irc_notice(client, status.nickname, MIAU_FLUSHQLOG,
 					days, hours, minutes);
 		}
@@ -2057,7 +2055,7 @@ miau_commands(char *command, char *param, connection_type *client)
 	}
 #endif /* ifdef PINGSTAT */
 
-	
+
 #ifdef FAKECMD
 	/* Developement only. */
 	else if (xstrcmp(command, "FAKECMD") == 0) {
@@ -2096,17 +2094,17 @@ miau_commands(char *command, char *param, connection_type *client)
 	else if (xstrcmp(command, "UPTIME") == 0) {
 		time_t now;
 		int seconds, minutes, hours, days;
-		
+
 		corr++;
 		time(&now);
 		now -= status.startup;
 		getuptime(now, &days, &hours, &minutes, &seconds),
-		
+
 		irc_notice(client, status.nickname, MIAU_UPTIME,
 				days, hours, minutes, seconds);
 	}
 #endif /* ifdef UPTIME */
-	
+
 #ifdef DUMPSTATUS
 	else if (xstrcmp(command, "DUMP") == 0) {
 		corr++;
@@ -2158,7 +2156,6 @@ miau_commands(char *command, char *param, connection_type *client)
 			server_check_list();
 		}
 	}
-		
 
 	else if (xstrcmp(command, "DIE") == 0) {
 		/*
@@ -2167,7 +2164,7 @@ miau_commands(char *command, char *param, connection_type *client)
 		 * need it.
 		 */
 		char *reason;
-		
+
 		reason = (param == NULL) ?
 			xstrdup(MIAU_DIE_CL) : xstrdup(param);
 		/*
@@ -2270,7 +2267,7 @@ run(void)
 			/* Not connected to server. */
 			report(SERV_TRYING, server->name, server->port);
 			servers.fresh = 0;
-		
+
 			/* Assume we have our desired nick. */
 			xfree(status.nickname);
 			status.nickname = xstrdup((char *)
@@ -2295,18 +2292,18 @@ run(void)
 					/* Clear getting_nick -counter. */
 					status.getting_nick = 0;
 					break;
-	
+
 				case CONN_SOCK:
 					error(SOCK_ERROPEN, net_errstr);
 					exit(ERR_CODE_NETWORK);
 					break;
-			
+
 				case CONN_LOOKUP:
 					error(SOCK_ERRRESOLVE, server->name);
 					server_drop(NULL);
 					server_change(1, 1);
-					break;	
-			
+					break;
+
 				case CONN_BIND:
 					if (cfg.bind) {
 						error(SOCK_ERRBINDHOST,
@@ -2320,7 +2317,7 @@ run(void)
 					}
 					exit(ERR_CODE_NETWORK);
 					break;
-					
+
 				case CONN_CONNECT:
 					/*
 					 * If timer was triggered, socket is
@@ -2333,22 +2330,22 @@ run(void)
 					}
 					server_change(1, 1);
 					break;
-					
+
 				case CONN_WRITE:
 					error(SOCK_ERRWRITE, server->name);
 					server_drop(NULL);
 					server_change(1, 0);
 					break;
-			
+
 				case CONN_OTHER:
 					error(SOCK_GENERROR, net_errstr);
 					exit(ERR_CODE_NETWORK);
 					break;
-			
+
 				default:
 					break;
 			}
-			
+
 			alarm(0);		/* Disable alarm. */
 			timers.connect = 0;
 		}
@@ -2383,7 +2380,7 @@ run(void)
 			dcc_socketsubscribe(&rfds, &wfds);
 		}
 #endif /* ifdef DCCBOUNCE */
-	
+
 		tv.tv_usec = 0;
 		tv.tv_sec = 1;
 
@@ -2408,7 +2405,7 @@ run(void)
 				if (c_newclient.socket != -1) {
 					c_newclient.offset = 0;
 					i_newclient.connected = 1;
-					
+
 					report(CLNT_CAUGHT,
 							i_newclient.hostname);
 				}
@@ -2474,7 +2471,7 @@ run(void)
 			}
 #endif /* ifdef DCCBOUNCE */
 		}
-		
+
 		check_timers();
 	}
 } /* static void run(void) */
@@ -2604,7 +2601,7 @@ check_config(void)
 {
 	int err = 0;
 #define REPORTERROR(x) { error(PARSE_MK, x); err++; }
-	
+
 	if (nicknames.nicks.head == NULL)	REPORTERROR("nicknames");
 	if (cfg.realname == NULL)		REPORTERROR("realname");
 	if (cfg.username == NULL)		REPORTERROR("username");
@@ -2613,7 +2610,7 @@ check_config(void)
 	if (connhostlist.list.head == NULL)	REPORTERROR("connhosts");
 	/*
 	 * Actually, we did we do this?
-	 * 
+	 *
 	if (! cfg.listenhost && cfg.bind) cfg.listenhost = xstrdup(cfg.bind);
 	 */
 
@@ -2674,7 +2671,7 @@ static void
 setup_atexit(void)
 {
 	int r;
-	
+
 	r = atexit(escape);
 	if (r != 0) {
 		error(ERR_CANT_ATEXIT);
@@ -2720,7 +2717,7 @@ main(int argc, char **argv)
 					char salt[3];
 					char *pass;
 					char *crypted;
-				
+
 					salt[0] = '\0';
 					srand(time(NULL));
 					randname(salt, 2, ' ');
@@ -2799,7 +2796,7 @@ main(int argc, char **argv)
 			error(MIAU_ERRFORK);
 			exit(EXIT_FAILURE);
 		}
-		
+
 		if (pid == 0) {
 			/*
 			 * Redirect stdout in file unless requested
@@ -2808,7 +2805,7 @@ main(int argc, char **argv)
 			 */
 			if (cfg.statelog == 1) {
 				FILE *f;
-				
+
 				f = freopen(FILE_LOG, "a", stdout);
 				if (f == NULL) {
 					error(MIAU_ERRFILE, cfg.home);
@@ -2835,7 +2832,7 @@ main(int argc, char **argv)
 
 			run();
 		}
-	
+
 		else {		/* pid != 0 */
 			pidfile = fopen(FILE_PID, "w");
 			if (pidfile == NULL) {
@@ -2845,7 +2842,7 @@ main(int argc, char **argv)
 			}
 			fprintf(pidfile, "%d\n", pid);
 			fclose(pidfile);
-			
+
 			report(MIAU_NICK, (char *) nicknames.nicks.head->data);
 			report(MIAU_FORKED, pid);
 		}
